==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/HandshakeSimpleSlash.md <==
# HandshakeSimpleSlash


```text
fontawesome-6/Solid/HandshakeSimpleSlash
```

```text
include('fontawesome-6/Solid/HandshakeSimpleSlash')
```



| Illustration | HandshakeSimpleSlash |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/HandshakeSimpleSlash.png) | ![illustration for HandshakeSimpleSlash](../../fontawesome-6/Solid/HandshakeSimpleSlash.Local.png) |




## HandshakeSimpleSlash

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HandshakeSimpleSlash
include('fontawesome-6/Solid/HandshakeSimpleSlash')

' renders the element
HandshakeSimpleSlash('HandshakeSimpleSlash', 'Handshake Simple Slash', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HandshakeSimpleSlash
include('fontawesome-6/Solid/HandshakeSimpleSlash')

' renders the element
HandshakeSimpleSlash('HandshakeSimpleSlash', 'Handshake Simple Slash', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/HandshakeSimpleSlash.md <==
# HandshakeSimpleSlash


```text
fontawesome-6/Solid/HandshakeSimpleSlash
```

```text
include('fontawesome-6/Solid/HandshakeSimpleSlash')
```



| Illustration | HandshakeSimpleSlash |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/HandshakeSimpleSlash.png) | ![illustration for HandshakeSimpleSlash](../../fontawesome-6/Solid/HandshakeSimpleSlash.Local.png) |




## HandshakeSimpleSlash

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HandshakeSimpleSlash
include('fontawesome-6/Solid/HandshakeSimpleSlash')

' renders the element
HandshakeSimpleSlash('HandshakeSimpleSlash', 'Handshake Simple Slash', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HandshakeSimpleSlash
include('fontawesome-6/Solid/HandshakeSimpleSlash')

' renders the element
HandshakeSimpleSlash('HandshakeSimpleSlash', 'Handshake Simple Slash', 'an optional tech label', 'an optional description')
@enduml
```
